/* ChanNode.h - NeonServ v5.6
 * Copyright (C) 2011-2012  Philipp Kreil (pk910)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with this program. If not, see <http://www.gnu.org/licenses/>. 
 */
#ifndef _ChanNode_h
#define _ChanNode_h
#include "main.h"

struct ChanUser;
struct trigger_cache;
struct ModeNode;
struct NeonSpamSettings;
struct timeq_entry;

#define CHANFLAG_RECEIVED_USERLIST  0x01
#define CHANFLAG_REQUESTED_CHANINFO 0x02
#define CHANFLAG_CHAN_REGISTERED    0x04
#define CHANFLAG_HAVE_INVISIBLES    0x08
#define CHANFLAG_REJOINING          0x10

#define CHANFLAG_SCRIPTFLAG1        0x80 /* used by neonserv_cmd_search */

struct ChanNode {
    char name[CHANNELLEN+1];
    char topic[TOPICLEN+1];
    struct ChanUser *user;
    unsigned int usercount;
    unsigned int botcount;
    unsigned char flags;
    struct ModeNode *modes;
    struct BanNode *bans;
    
    struct trigger_cache *trigger;
    int channel_id;
    
    struct NeonSpamSettings *spam_settings;
	
    void *rejoin_bots;
    struct timeq_entry *rejoin_timeout;
    
    struct ChanNode *next;
};

#ifndef DND_FUNCTIONS
void init_ChanNode();
void free_ChanNode();
/* MODULAR ACCESSIBLE */ int is_valid_chan(const char *name);
/* MODULAR ACCESSIBLE */ struct ChanNode* getAllChans(struct ChanNode *last);
/* MODULAR ACCESSIBLE */ struct ChanNode* getChanByName(const char *name);
struct ChanNode* addChannel(const char *chan);
/* MODULAR ACCESSIBLE */ int getChannelCount();
/* MODULAR ACCESSIBLE */ int getChanUserCount();
/* MODULAR ACCESSIBLE */ int getChanBanCount();
void delChannel(struct ChanNode* chan, int freeChan);
void freeChanNode(struct ChanNode* chan);
int checkChannelVisibility(struct ChanNode* chan);
#endif
#endif